import setuptools
   
setuptools.setup(
    name="jade_helper",
    version="0.0.4",
    author="Jade Perdereau",
    author_email="jade.perdereau@free.fr",
    description="Package creation test",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
